@@ -156,22 +156,28 @@ write_cue_activate_cb (NautilusMenuItem *item,
 static int
 desktop_uri_get_drive_id (const char *uri)
 {
-        GnomeVFSResult result;
-        int            file_size;
-	char          *file_contents;
+	GnomeVFSResult result;
+	int	       file_size;
 	GKeyFile      *key_file;	
-	char *         id;
-	int            drive_id = -1;
+	char	      *file_contents = NULL;
+	char	      *id	     = NULL;
+	int	       drive_id	     = -1;
 
 	key_file = g_key_file_new ();
+
 	result = eel_read_entire_file (uri, &file_size, &file_contents);
-	g_key_file_load_from_data (key_file, file_contents, file_size, G_KEY_FILE_NONE, NULL);
+	if (result != GNOME_VFS_OK)
+		goto done;
+
+	if (! g_key_file_load_from_data (key_file, file_contents, file_size, G_KEY_FILE_NONE, NULL))
+		goto done;
 
 	id = g_key_file_get_string (key_file, "Desktop Entry", "X-Gnome-Drive", NULL);
 	if (id) {
-                drive_id = atol (id);
+		drive_id = atol (id);
 	}
 
+ done:
 	g_free (id);
 	g_free (file_contents);
 	g_key_file_free (key_file);
